==> owncloud-10.0.3.tgz: owncloud/apps/federatedfilesharing/l10n/el.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Ομόσπονδος διαμοιρασμός",
    "Invalid Federated Cloud ID" : "Μη έγκυρο Federated Cloud ID",
    "Sharing %s failed, because this item is already shared with %s" : "Ο διαμοιρασμός του %s απέτυχε, γιατί το αντικείμενο είναι διαμοιρασμένο ήδη με τον χρήστη %s",
    "Not allowed to create a federated share with the same user" : "Δεν είναι επιτρεπτή η δημιουργία ομόσπονδου διαμοιρασμού με τον ίδιο διακομιστή χρήστη",
    "File is already shared with %s" : "Το αρχείο διαμοιράζεται ήδη με τον %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Αποτυχία διαμοιρασμού %s, δεν βρέθηκε το %s, μπορεί ο διακομιστής να είναι προσωρινά απροσπέλαστος.",
    "You received \"/%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Λάβατε το \"/%3$s\" ως απομακρυσμένο διαμοιρασμό από %1$s (εκ μέρους του %2$s)",
    "You received \"/%3$s\" as a remote share from %1$s" : "Λάβατε το  \"/%3$s\"  ως απομακρυσμένο διαμοιρασμό από  %1$s",
    "Accept" : "Αποδοχή",
    "Decline" : "Απόρριψη",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Διαμοιρασμός με εμένα μέσω του #ownCloud Federated Cloud ID μου, δείτε %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Διαμοιρασμός με εμένα μέσω του #ownCloud Federated Cloud ID μου",
    "Federated Cloud Sharing" : "Διαμοιρασμός σε ομόσπονδα σύννεφα ",
    "Open documentation" : "Ανοιχτή τεκμηρίωση.",
    "Allow users on this server to send shares to other servers" : "Να επιτρέπεται σε χρήστες αυτού του διακομιστή να στέλνουν διαμοιρασμένους φακέλους σε άλλους διακομιστές",
    "Allow users on this server to receive shares from other servers" : "Να επιτρέπεται στους χρίστες του διακομιστή να λαμβάνουν διαμοιρασμένα αρχεία από άλλους διακομιστές",
    "Federated Cloud" : "Federated σύννεφο",
    "Your Federated Cloud ID:" : "Το ID σας στο Federated Cloud:",
    "Share it:" : "Μοιραστείτε το:",
    "Add to your website" : "Προσθήκη στην ιστοσελίδα σας",
    "Share with me via ownCloud" : "Διαμοιρασμός με εμένα μέσω του ",
    "HTML Code:" : "Κώδικας HTML:"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.10.tgz: owncloud/apps/federatedfilesharing/l10n/el.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Ομόσπονδος διαμοιρασμός",
    "Invalid Federated Cloud ID" : "Μη έγκυρο Federated Cloud ID",
    "Sharing %s failed, because this item is already shared with %s" : "Ο διαμοιρασμός του %s απέτυχε, γιατί το αντικείμενο είναι διαμοιρασμένο ήδη με τον χρήστη %s",
    "Not allowed to create a federated share with the same user" : "Δεν είναι επιτρεπτή η δημιουργία ομόσπονδου διαμοιρασμού με τον ίδιο διακομιστή χρήστη",
    "File is already shared with %s" : "Το αρχείο διαμοιράζεται ήδη με τον %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Αποτυχία διαμοιρασμού %s, δεν βρέθηκε το %s, μπορεί ο διακομιστής να είναι προσωρινά απροσπέλαστος.",
    "You received \"/%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Λάβατε το \"/%3$s\" ως απομακρυσμένο διαμοιρασμό από %1$s (εκ μέρους του %2$s)",
    "You received \"/%3$s\" as a remote share from %1$s" : "Λάβατε το  \"/%3$s\"  ως απομακρυσμένο διαμοιρασμό από  %1$s",
    "Accept" : "Αποδοχή",
    "Decline" : "Απόρριψη",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Διαμοιρασμός με εμένα μέσω του #ownCloud Federated Cloud ID μου, δείτε %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Διαμοιρασμός με εμένα μέσω του #ownCloud Federated Cloud ID μου",
    "Federated Cloud Sharing" : "Διαμοιρασμός σε ομόσπονδα σύννεφα ",
    "Open documentation" : "Ανοιχτή τεκμηρίωση.",
    "Allow users on this server to send shares to other servers" : "Να επιτρέπεται σε χρήστες αυτού του διακομιστή να στέλνουν διαμοιρασμένους φακέλους σε άλλους διακομιστές",
    "Allow users on this server to receive shares from other servers" : "Να επιτρέπεται στους χρίστες του διακομιστή να λαμβάνουν διαμοιρασμένα αρχεία από άλλους διακομιστές",
    "Federated Cloud" : "Federated σύννεφο",
    "Your Federated Cloud ID:" : "Το ID σας στο Federated Cloud:",
    "Share it:" : "Μοιραστείτε το:",
    "Add to your website" : "Προσθήκη στην ιστοσελίδα σας",
    "Share with me via ownCloud" : "Διαμοιρασμός με εμένα μέσω του ",
    "HTML Code:" : "Κώδικας HTML:",
    "Add to your ownCloud" : "Προσθήκη στο ownCloud σου"
},
"nplurals=2; plural=(n != 1);");
